@@ -16,6 +16,7 @@ import json
 
 import kaskada.api.v1alpha.compute_pb2_grpc as compute_grpc
 import kaskada.api.v1alpha.table_pb2_grpc as table_grpc
+import kaskada.api.v1alpha.staged_file_pb2_grpc as staging_grpc
 import kaskada.api.v1alpha.view_pb2_grpc as view_grpc
 
 class Client(object):
@@ -57,6 +58,7 @@ class Client(object):
         self.computeStub = compute_grpc.ComputeServiceStub(channel)
         self.tableStub = table_grpc.TableServiceStub(channel)
         self.viewStub = view_grpc.ViewServiceStub(channel)
+        self.stagingStub = staging_grpc.StagedFileServiceStub(channel)
         self.metadata = metadata
         if engine is not None:
             self.metadata.append(('x-engine', engine))
